@@ -1,4 +1,4 @@
-package EAI::Wrap 1.904;
+package EAI::Wrap 1.905;
 
 use strict; use feature 'unicode_strings'; use warnings;
 use Exporter qw(import); use Data::Dumper qw(Dumper); use File::Copy qw(copy move); use Cwd qw(chdir); use Archive::Extract ();
@@ -216,7 +216,7 @@ sub redoFiles ($) {
 		return 0;
 	}
 	chdir($execute{homedir});
-	return 1;
+	return checkFiles($arg);
 }
 
 # get local file(s) from source into homedir
@@ -267,7 +267,7 @@ sub getLocalFiles ($) {
 		return 0;
 	}
 	$process->{successfullyDone}.="getLocalFiles";
-	return 1;
+	return checkFiles($arg);
 }
 
 # get file/s (can also be a glob for multiple files) from FTP into homedir
@@ -282,7 +282,7 @@ sub getFilesFromFTP ($) {
 			return redoFiles($arg);
 		} else {
 			if ($File->{filename}) {
-				return EAI::FTP::fetchFiles($FTP,{firstRunSuccess=>$execute{firstRunSuccess},homedir=>$execute{homedir},fileToRetrieve=>$File->{filename},fileToRetrieveOptional=>$File->{optional},retrievedFiles=>$execute{retrievedFiles}});
+				EAI::FTP::fetchFiles($FTP,{firstRunSuccess=>$execute{firstRunSuccess},homedir=>$execute{homedir},fileToRetrieve=>$File->{filename},fileToRetrieveOptional=>$File->{optional},retrievedFiles=>$execute{retrievedFiles}}) or $logger->warn("EAI::FTP::fetchFiles not successful");
 			} else {
 				$logger->error("no \$File->{filename} given, can't get it from FTP");
 				$process->{hadErrors} = 1;
@@ -295,7 +295,7 @@ sub getFilesFromFTP ($) {
 		return 0;
 	}
 	$process->{successfullyDone}.="getFilesFromFTP";
-	return 1;
+	return checkFiles($arg);
 }
 
 # general procedure to get files from FTP or locally
@@ -1022,8 +1022,7 @@ EAI::Wrap - framework for easy creation of Enterprise Application Integration ta
     openFTPConn(\%common) or die;
     while (!$execute{processEnd}) {
     	for my $load (@loads) {
-    		getFilesFromFTP($load);
-    		if (checkFiles($load)) {
+    		if (getFilesFromFTP($load)) {
     			readFileData($load);
     			dumpDataIntoDB($load);
     			markProcessed($load);
@@ -1123,7 +1122,7 @@ The INIT procedure is executed at the task script initialization (when EAI::Wrap
 
 =head2 API: High-level subs
 
-Following are the high level subs that can be called for a standard workflow. Most of them accumulate their sub names to prevent any further call in a faulting loop, when they alrady ran successfully.
+Following are the high level subs that can be called for a standard workflow. Most of them accumulate their sub names in process{successfullyDone} to prevent any further call in a faulting loop, when they alrady ran successfully. Also process{hadErrors} is set in case of errors to provide for error repeating. Downloaded files are collected in process{filenames} and completely processed files in process{filesProcessed}.
 
 =over 4
 
@@ -1161,13 +1160,13 @@ redo file from redo directory if specified (C<$common{task}{redoFile}> is being
 
 argument $arg (ref to current load or common)
 
-get local file(s) from source into homedir, uses C<$File-E<gt>{filename}>, C<$File-E<gt>{extension}> and C<$File-E<gt>{avoidRenameForRedo}>. Arguments are fetched from common or loads[i], using File parameter.
+get local file(s) from source into homedir, checks files for continuation of processing and extract archives if needed. Arguments are fetched from common or loads[i], using File parameter. The processed files are put into process->{filenames} (always runs in a faulting loop). Uses C<$File-E<gt>{filename}>, C<$File-E<gt>{extension}> and C<$File-E<gt>{avoidRenameForRedo}>.
 
 =item getFilesFromFTP ($)
 
 argument $arg (ref to current load or common)
 
-get file/s (can also be a glob for multiple files) from FTP into homedir and extract archives if needed. Arguments are fetched from common or loads[i], using File and FTP parameters.
+get file/s (can also be a glob for multiple files) from FTP into homedir, checks files for continuation of processing and extract archives if needed. Arguments are fetched from common or loads[i], using File and FTP parameters. The processed files are put into process->{filenames} (always runs in a faulting loop).
 
 =item getFiles ($)
 
@@ -1179,13 +1178,13 @@ combines above two procedures in a general procedure to get files from FTP or lo
 
 argument $arg (ref to current load or common)
 
-check files for continuation of processing and extract archives if needed. Arguments are fetched from common or loads[i], using File parameter. The processed files are put into process->{filenames} (always runs in a faulting loop).
+check files for continuation of processing and extract archives if needed. Arguments are fetched from common or loads[i], using File parameter. The processed files are put into process->{filenames} (always runs in a faulting loop). Important: files (their filenames) not retrieved by getFilesFromFTP or getLocalFiles have to be put into $execute{retrievedFiles} (e.g. push @{$execute{retrievedFiles}}, $filenameTobeChecked)!
 
 =item extractArchives ($)
 
 argument $arg (ref to current load or common)
 
-extract files from archive. Arguments are fetched from common or loads[i], using only the process->{filenames} parameter that was filled by checkFiles. 
+extract files from archive (only one archive is allowed). Arguments are fetched from common or loads[i], using only the process->{filenames} parameter that was filled by checkFiles. If not being called by getFilesFromFTP/getLocalFiles and checkFiles @{$process{filenames}} has to contain the archive filename.
 
 =item getAdditionalDBData ($;$)
 
@@ -1963,7 +1962,7 @@ interactive options (are not checked), can be used to pass arbitrary data via co
 
 =item onlyExecFor
 
-mark loads to only be executed when $common{task}{execOnly} !~ $load->{process}{onlyExecFor}
+define loads to only be executed when $common{task}{execOnly} !~ $load->{process}{onlyExecFor}. Empty onlyExecFor loads are always executed regardless of $common{task}{execOnly}
 
 =item successfullyDone
 
@@ -1995,7 +1994,7 @@ optional custom timestamp to be added to filenames moved to History/HistoryUploa
 
 =item execOnly
 
-used to remove loads where $common{task}{execOnly} !~ $load->{process}{onlyExecFor}
+do not execute loads where $common{task}{execOnly} !~ $load->{process}{onlyExecFor}. Empty onlyExecFor loads are always executed regardless of $common{task}{execOnly}
 
 =item ignoreNoTest
 
